@@ -86,37 +86,37 @@ var _ = Describe("Clone controller reconcile loop", func() {
 
 	It("Should return success if a PVC with no annotations is passed, due to it being ignored", func() {
 		reconciler = createCloneReconciler(createPvc("testPvc1", "default", map[string]string{}, nil))
-		_, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 	})
 
 	It("Should return success if no PVC can be found, due to it not existing", func() {
 		reconciler = createCloneReconciler()
-		_, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 	})
 
 	It("Should return success if no PVC can be found due to not existing in passed namespace", func() {
 		reconciler = createCloneReconciler(createPvc("testPvc1", "default", map[string]string{AnnEndpoint: testEndPoint}, nil))
-		_, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "invalid"}})
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "invalid"}})
 		Expect(err).ToNot(HaveOccurred())
 	})
 
 	It("Should return success if a PVC with clone request annotation and cloneof is passed, due to it being ignored", func() {
 		reconciler = createCloneReconciler(createPvc("testPvc1", "default", map[string]string{AnnCloneRequest: "cloneme", AnnCloneOf: "something"}, nil))
-		_, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 	})
 
 	It("Should return success if target pod is not ready", func() {
 		reconciler = createCloneReconciler(createPvc("testPvc1", "default", map[string]string{AnnCloneRequest: "cloneme"}, nil))
-		_, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 	})
 
 	It("Should return error if target pod annotation is invalid", func() {
 		reconciler = createCloneReconciler(createPvc("testPvc1", "default", map[string]string{AnnCloneRequest: "cloneme", AnnPodReady: "invalid"}, nil))
-		_, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).To(HaveOccurred())
 		Expect(err.Error()).To(ContainSubstring(fmt.Sprintf("error parsing %s annotation", AnnPodReady)))
 	})
@@ -137,7 +137,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		By("Verifying no source pod exists")
 		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
@@ -146,7 +146,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
 		Expect(err).ToNot(HaveOccurred())
 		Expect(testPvc.Annotations[AnnCloneSourcePod]).To(Equal("default-testPvc1-source-pod"))
-		Expect(reconciler.hasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeTrue())
+		Expect(HasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeTrue())
 	})
 
 	DescribeTable("Should NOT create new source pod if source PVC is in use", func(podFunc func(*corev1.PersistentVolumeClaim) *corev1.Pod) {
@@ -167,7 +167,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		result, err := reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		result, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		Expect(result.Requeue).To(BeTrue())
 		By("Verifying source pod does not exist")
@@ -214,7 +214,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		By("Verifying source pod exists")
 		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
@@ -273,7 +273,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).To(HaveOccurred())
 		Expect(err.Error()).To(ContainSubstring("missing required " + AnnUploadClientName + " annotation"))
 	})
@@ -291,7 +291,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		By("Verifying source pod exists")
 		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
@@ -299,10 +299,9 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		Expect(sourcePod.GetLabels()[CloneUniqueID]).To(Equal("default-testPvc1-source-pod"))
 	})
 
-	It("Should update the cloneof when complete", func() {
-		testPvc := createPvc("testPvc1", "default", map[string]string{
-			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient"}, nil)
-		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil))
+	DescribeTable("Should update the cloneof when complete,", func(createSourcePvcFunc func() *corev1.PersistentVolumeClaim, createTargetPvcFunc func() *corev1.PersistentVolumeClaim) {
+		testPvc := createTargetPvcFunc()
+		reconciler = createCloneReconciler(testPvc, createSourcePvcFunc())
 		By("Setting up the match token")
 		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
 		reconciler.tokenValidator.(*FakeValidator).Name = "source"
@@ -312,13 +311,13 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		By("Verifying the PVC now has a source pod name")
 		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
 		Expect(err).ToNot(HaveOccurred())
 		Expect(testPvc.Annotations[AnnCloneSourcePod]).To(Equal("default-testPvc1-source-pod"))
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		By("Verifying source pod exists")
 		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
@@ -327,13 +326,21 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying the PVC now has a finalizer")
 		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
 		Expect(err).ToNot(HaveOccurred())
-		Expect(reconciler.hasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeTrue())
+		Expect(HasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeTrue())
 		By("Updating the PVC to completed")
 		testPvc.Annotations = map[string]string{
 			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod", AnnPodPhase: string(corev1.PodSucceeded)}
 		err = reconciler.client.Update(context.TODO(), testPvc)
 		Expect(err).ToNot(HaveOccurred())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+
+		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
+		Expect(err).ToNot(HaveOccurred())
+		sourcePod.Status.Phase = corev1.PodSucceeded
+		err = reconciler.client.Update(context.TODO(), sourcePod)
+		Expect(err).ToNot(HaveOccurred())
+		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
+
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
 		Expect(err).ToNot(HaveOccurred())
@@ -341,7 +348,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
 		Expect(err).ToNot(HaveOccurred())
 		Expect(sourcePod).ToNot(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
 		By("Checking error event recorded")
 		event := <-reconciler.recorder.(*record.FakeRecorder).Events
@@ -353,13 +360,49 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		testPvc = &corev1.PersistentVolumeClaim{}
 		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
 		Expect(err).ToNot(HaveOccurred())
-		Expect(reconciler.hasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeFalse())
-	})
+		Expect(HasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeFalse())
+	},
+		Entry("filesystem mode",
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("source", "default", map[string]string{}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("testPvc1", "default", map[string]string{
+					AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient"}, nil)
+			},
+		),
+		Entry("block mode",
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("source", "default", map[string]string{}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("testPvc1", "default", map[string]string{
+					AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient"}, nil)
+			},
+		),
+		Entry("block -> filesystem",
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("source", "default", map[string]string{}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("testPvc1", "default", map[string]string{
+					AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient"}, nil)
+			},
+		),
+		Entry("filesystem -> block",
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("source", "default", map[string]string{}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("testPvc1", "default", map[string]string{
+					AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient"}, nil)
+			},
+		),
+	)
 
-	It("Should update the cloneof when complete, block mode", func() {
-		testPvc := createBlockPvc("testPvc1", "default", map[string]string{
-			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient"}, nil)
-		reconciler = createCloneReconciler(testPvc, createBlockPvc("source", "default", map[string]string{}, nil))
+	DescribeTable("Should error when", func(createSourcePvcFunc func() *corev1.PersistentVolumeClaim, createTargetPvcFunc func() *corev1.PersistentVolumeClaim, expectedError string) {
+		testPvc := createTargetPvcFunc()
+		reconciler = createCloneReconciler(testPvc, createSourcePvcFunc())
 		By("Setting up the match token")
 		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
 		reconciler.tokenValidator.(*FakeValidator).Name = "source"
@@ -369,81 +412,51 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
-		Expect(err).ToNot(HaveOccurred())
-		By("Verifying the PVC now has a source pod name")
-		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(testPvc.Annotations[AnnCloneSourcePod]).To(Equal("default-testPvc1-source-pod"))
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
-		Expect(err).ToNot(HaveOccurred())
-		By("Verifying source pod exists")
-		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(sourcePod.GetLabels()[CloneUniqueID]).To(Equal("default-testPvc1-source-pod"))
-		By("Verifying the PVC now has a finalizer")
-		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(reconciler.hasFinalizer(testPvc, cloneSourcePodFinalizer)).To(BeTrue())
-		By("Updating the PVC to completed")
-		testPvc.Annotations = map[string]string{
-			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod", AnnPodPhase: string(corev1.PodSucceeded)}
-		err = reconciler.client.Update(context.TODO(), testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
-		Expect(err).ToNot(HaveOccurred())
-		err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "testPvc1", Namespace: "default"}, testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(testPvc.GetAnnotations()[AnnCloneOf]).To(Equal("true"))
-		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(sourcePod).ToNot(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
-		Expect(err).ToNot(HaveOccurred())
-		By("Checking error event recorded")
-		event := <-reconciler.recorder.(*record.FakeRecorder).Events
-		Expect(event).To(ContainSubstring(cloneComplete))
-		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(sourcePod).To(BeNil())
-	})
-
-	It("Should error when source and target volume modes do not match (fs->block)", func() {
-		testPvc := createBlockPvc("testPvc1", "default", map[string]string{
-			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
-		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil))
-		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
-		By("Verifying no source pod exists")
-		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
-		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).To(HaveOccurred())
-		Expect(err.Error()).To(ContainSubstring("source volumeMode (Filesystem) and target volumeMode (Block) do not match"))
-	})
-
-	It("Should error when source and target volume modes do not match (block->fs)", func() {
-		testPvc := createPvc("testPvc1", "default", map[string]string{
-			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
-		reconciler = createCloneReconciler(testPvc, createBlockPvc("source", "default", map[string]string{}, nil))
-		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
-		By("Verifying no source pod exists")
-		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
-		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
-		Expect(err).To(HaveOccurred())
-		Expect(err.Error()).To(ContainSubstring("source volumeMode (Block) and target volumeMode (Filesystem) do not match"))
-	})
-
+		Expect(err.Error()).To(ContainSubstring(expectedError))
+	},
+		Entry("source and target content type do not match (kubevirt->archive)",
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("source", "default", map[string]string{}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("testPvc1", "default", map[string]string{
+					AnnContentType: "archive", AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
+			},
+			"source contentType (kubevirt) and target contentType (archive) do not match",
+		),
+		Entry("source and target content type do not match (archive->kubevirt)",
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("source", "default", map[string]string{AnnContentType: "archive"}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("testPvc1", "default", map[string]string{
+					AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
+			},
+			"source contentType (archive) and target contentType (kubevirt) do not match",
+		),
+		Entry("content type is not kubevirt, and source and target volume modes do not match (fs->block)",
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("source", "default", map[string]string{AnnContentType: "archive"}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("testPvc1", "default", map[string]string{
+					AnnContentType: "archive", AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
+			},
+			"source volumeMode (Filesystem) and target volumeMode (Block) do not match",
+		),
+		Entry("content type is not kubevirt, and source and target volume modes do not match (block->fs)",
+			func() *corev1.PersistentVolumeClaim {
+				return createBlockPvc("source", "default", map[string]string{AnnContentType: "archive"}, nil)
+			},
+			func() *corev1.PersistentVolumeClaim {
+				return createPvc("testPvc1", "default", map[string]string{
+					AnnContentType: "archive", AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
+			},
+			"source volumeMode (Block) and target volumeMode (Filesystem) do not match",
+		),
+	)
 })
 
 var _ = Describe("ParseCloneRequestAnnotation", func() {
@@ -633,7 +646,7 @@ var _ = Describe("TokenValidation", func() {
 				},
 			},
 		}
-		err = validateCloneToken(v, source, target)
+		err = validateCloneTokenPVC(v, source, target)
 		if expectedSuccess {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(reflect.DeepEqual(p, goodTokenData())).To(BeTrue())
